==> estateplat-common-1.2.4-20191216.072042-218-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxJg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.util.Date;

/**
 * @version 1.0, 2018/3/13
 * @auther <a href="mailto:jiangganzhi@gtmap.cn" >jiangganhzi on 2018/3/13.</a>
 * @description 不动产收费信息结果（用于发票信息）
 */
@Table(name = "BDC_SFXX_JG")
public class BdcSfxxJg {
    @Id
    private String sfxxid;//收费信息ID

    private String fkrqc;//付款人全称

    private String fkrzh;//付款人账号

    private String fkrkhyh;//付款人开户银行

    private String skrqc;//收款人全称

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String fpbh;//发票编号（年份加证书流水号）

    private Date tzrq;//填制日期

    private String fph;//发票号

    private String cpr;//出票人

    private double zje;//总金额

    private String fkfs;//付款方式

    private String zsdwmc;//执收单位名称

    private String zsdwdm;//执收单位代码

    private String fpyh;//发票印号

    private Date sbsj;//上报时间

    private Date zfsj;//作废时间

    private String zfyy;//作废原因

    private String fpzt;//发票状态
    private String sfzt;//收费状态
    private String bz;//备注
    private String sfztczr;//收费状态操作人

    private Date sfztczrq;//收费状态操作日期
    private String pjwybsm;//票据唯一标识码

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getFkrqc() {
        return fkrqc;
    }

    public void setFkrqc(String fkrqc) {
        this.fkrqc = fkrqc;
    }

    public String getFkrzh() {
        return fkrzh;
    }

    public void setFkrzh(String fkrzh) {
        this.fkrzh = fkrzh;
    }

    public String getFkrkhyh() {
        return fkrkhyh;
    }

    public void setFkrkhyh(String fkrkhyh) {
        this.fkrkhyh = fkrkhyh;
    }

    public String getSkrqc() {
        return skrqc;
    }

    public void setSkrqc(String skrqc) {
        this.skrqc = skrqc;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getFpbh() {
        return fpbh;
    }

    public void setFpbh(String fpbh) {
        this.fpbh = fpbh;
    }

    public Date getTzrq() {
        return tzrq;
    }

    public void setTzrq(Date tzrq) {
        this.tzrq = tzrq;
    }

    public String getFph() {
        return fph;
    }

    public void setFph(String fph) {
        this.fph = fph;
    }

    public double getZje() {
        return zje;
    }

    public void setZje(double zje) {
        this.zje = zje;
    }

    public String getCpr() { return cpr; }

    public void setCpr(String cpr) { this.cpr = cpr; }

    public String getFkfs() { return fkfs; }

    public void setFkfs(String fkfs) { this.fkfs = fkfs; }

    public String getZsdwmc() { return zsdwmc; }

    public void setZsdwmc(String zsdwmc) { this.zsdwmc = zsdwmc; }

    public String getZsdwdm() { return zsdwdm; }

    public void setZsdwdm(String zsdwdm) { this.zsdwdm = zsdwdm; }

    public String getFpyh() { return fpyh; }

    public void setFpyh(String fpyh) { this.fpyh = fpyh; }

    public Date getSbsj(){
        return sbsj;
    }

    public void setSbsj(Date sbsj){
        this.sbsj = sbsj;
    }

    public Date getZfsj(){
        return zfsj;
    }

    public void setZfsj(Date zfsj){
        this.zfsj = zfsj;
    }

    public String getZfyy(){
        return zfyy;
    }

    public void setZfyy(String zfyy){
        this.zfyy = zfyy;
    }

    public String getFpzt(){
        return fpzt;
    }

    public void setFpzt(String fpzt){
        this.fpzt = fpzt;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfztczr() {
        return sfztczr;
    }

    public void setSfztczr(String sfztczr) {
        this.sfztczr = sfztczr;
    }

    public Date getSfztczrq() {
        return sfztczrq;
    }

    public void setSfztczrq(Date sfztczrq) {
        this.sfztczrq = sfztczrq;
    }

    public String getPjwybsm() {
        return pjwybsm;
    }

    public void setPjwybsm(String pjwybsm) {
        this.pjwybsm = pjwybsm;
    }
}

==> estateplat-common-1.2.4-20201016.082427-463-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxJg.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import javax.persistence.Id;
import java.util.Date;

/**
 * @version 1.0, 2018/3/13
 * @auther <a href="mailto:jiangganzhi@gtmap.cn" >jiangganhzi on 2018/3/13.</a>
 * @description 不动产收费信息结果（用于发票信息）
 */
@Table(name = "BDC_SFXX_JG")
public class BdcSfxxJg {
    @Id
    private String sfxxid;//收费信息ID

    private String fkrqc;//付款人全称

    private String fkrzh;//付款人账号

    private String fkrkhyh;//付款人开户银行

    private String skrqc;//收款人全称

    private String skrzh;//收款人账号

    private String skrkhyh;//收款人开户银行

    private String fpbh;//发票编号（年份加证书流水号）

    private Date tzrq;//填制日期

    private String fph;//发票号

    private String cpr;//出票人

    private double zje;//总金额

    private String fkfs;//付款方式

    private String zsdwmc;//执收单位名称

    private String zsdwdm;//执收单位代码

    private String fpyh;//发票印号

    private Date sbsj;//上报时间

    private Date zfsj;//作废时间

    private String zfyy;//作废原因

    private String fpzt;//发票状态
    private String sfzt;//收费状态
    private String bz;//备注
    private String sfztczr;//收费状态操作人

    private Date sfztczrq;//收费状态操作日期
    private String pjwybsm;//票据唯一标识码

    private String dyzt;// 打印状态

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public String getFkrqc() {
        return fkrqc;
    }

    public void setFkrqc(String fkrqc) {
        this.fkrqc = fkrqc;
    }

    public String getFkrzh() {
        return fkrzh;
    }

    public void setFkrzh(String fkrzh) {
        this.fkrzh = fkrzh;
    }

    public String getFkrkhyh() {
        return fkrkhyh;
    }

    public void setFkrkhyh(String fkrkhyh) {
        this.fkrkhyh = fkrkhyh;
    }

    public String getSkrqc() {
        return skrqc;
    }

    public void setSkrqc(String skrqc) {
        this.skrqc = skrqc;
    }

    public String getSkrzh() {
        return skrzh;
    }

    public void setSkrzh(String skrzh) {
        this.skrzh = skrzh;
    }

    public String getSkrkhyh() {
        return skrkhyh;
    }

    public void setSkrkhyh(String skrkhyh) {
        this.skrkhyh = skrkhyh;
    }

    public String getFpbh() {
        return fpbh;
    }

    public void setFpbh(String fpbh) {
        this.fpbh = fpbh;
    }

    public Date getTzrq() {
        return tzrq;
    }

    public void setTzrq(Date tzrq) {
        this.tzrq = tzrq;
    }

    public String getFph() {
        return fph;
    }

    public void setFph(String fph) {
        this.fph = fph;
    }

    public double getZje() {
        return zje;
    }

    public void setZje(double zje) {
        this.zje = zje;
    }

    public String getCpr() { return cpr; }

    public void setCpr(String cpr) { this.cpr = cpr; }

    public String getFkfs() { return fkfs; }

    public void setFkfs(String fkfs) { this.fkfs = fkfs; }

    public String getZsdwmc() { return zsdwmc; }

    public void setZsdwmc(String zsdwmc) { this.zsdwmc = zsdwmc; }

    public String getZsdwdm() { return zsdwdm; }

    public void setZsdwdm(String zsdwdm) { this.zsdwdm = zsdwdm; }

    public String getFpyh() { return fpyh; }

    public void setFpyh(String fpyh) { this.fpyh = fpyh; }

    public Date getSbsj(){
        return sbsj;
    }

    public void setSbsj(Date sbsj){
        this.sbsj = sbsj;
    }

    public Date getZfsj(){
        return zfsj;
    }

    public void setZfsj(Date zfsj){
        this.zfsj = zfsj;
    }

    public String getZfyy(){
        return zfyy;
    }

    public void setZfyy(String zfyy){
        this.zfyy = zfyy;
    }

    public String getFpzt(){
        return fpzt;
    }

    public void setFpzt(String fpzt){
        this.fpzt = fpzt;
    }

    public String getSfzt() {
        return sfzt;
    }

    public void setSfzt(String sfzt) {
        this.sfzt = sfzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfztczr() {
        return sfztczr;
    }

    public void setSfztczr(String sfztczr) {
        this.sfztczr = sfztczr;
    }

    public Date getSfztczrq() {
        return sfztczrq;
    }

    public void setSfztczrq(Date sfztczrq) {
        this.sfztczrq = sfztczrq;
    }

    public String getPjwybsm() {
        return pjwybsm;
    }

    public void setPjwybsm(String pjwybsm) {
        this.pjwybsm = pjwybsm;
    }

    public String getDyzt() {
        return dyzt;
    }

    public void setDyzt(String dyzt) {
        this.dyzt = dyzt;
    }
}
